# build binary pam-change-pw
#
# this makefile requires the builder make from vault $product\builder\tools\MAKETLS
# and cygwin
#

#
# we use sh.exe of cygwin as shell 
#
SHELL=sh

# two local env variables are used. if you're not located in sifi, you should copy the needed files to a local path and set these env 
# variables to your local paths
ifndef VAULT_BINARIES
	VAULT_BINARIES=//innovaphone.sifi/dfs/build/binaries
else
	VAULT_BINARIES:=$(shell echo '$(VAULT_BINARIES)' | sed -e 's/\\/\//g')
endif

#
# as cygwin breaks file permissions when run outside its own shell, we'll fix these by using functions which execute icacls afterwards
#
mkdir_make = mkdir -p $(1);icacls $(1) /reset /T

ARM_INCLUDE1:=$(VAULT_BINARIES)/$(shell cat binaries/cross-compiler.txt)/armv5te/include
ARM_INCLUDE2:=$(ARM_INCLUDE1)/arm-linux-gnueabi
ARM_GCC_INCLUDE:=$(T)/arm-4.9.2-linux-gnu/lib/gcc/arm-linux-gnueabi/4.9.2/include
ARM_LIB:=$(VAULT_BINARIES)/$(shell cat binaries/cross-compiler.txt)/armv5te/lib

I386_INCLUDE1:=$(VAULT_BINARIES)/$(shell cat binaries/cross-compiler.txt)/i386/include
I386_INCLUDE2:=$(I386_INCLUDE1)/i386-linux-gnu
I386_GCC_INCLUDE:=$(T)/i486-4.9.2-linux-gnu/lib/gcc/i486-linux-gnu/4.9.2/include
I386_LIB:=$(VAULT_BINARIES)/$(shell cat binaries/cross-compiler.txt)/i386/lib

GCC_FLAGS=-nostdinc -nostdlib
OUT=pam-change-pw
BUILD_ARMV5TE=build_armv5te
BUILD_I386=build_i386

ARM_STDLIBS:=$(ARM_LIB)/crt1.o $(ARM_LIB)/crti.o $(ARM_LIB)/libc.so.6 $(ARM_LIB)/libc_nonshared.a $(ARM_LIB)/ld-linux.so.3 $(ARM_LIB)/crtn.o
ARM_STDINC:=-I $(ARM_INCLUDE1) -I $(ARM_INCLUDE2) -I $(ARM_GCC_INCLUDE)
I386_STDLIBS:=$(I386_LIB)/crt1.o $(I386_LIB)/crti.o $(I386_LIB)/libc.so.6 $(I386_LIB)/libc_nonshared.a $(I386_LIB)/ld-linux.so.2 $(I386_LIB)/crtn.o
I386_STDINC:=-I $(I386_INCLUDE1) -I $(I386_INCLUDE2) -I $(I386_GCC_INCLUDE)

# list all c files here
C_FILES=pam-change-pw.c

# list all additional libraries here
ARM_LIBS:=$(ARM_LIB)/libpam.so.0 $(ARM_LIB)/libdl.so.2
I386_LIBS:=$(I386_LIB)/libpam.so.0 $(I386_LIB)/libdl.so.2

.PHONY: armv5te i386

armv5te:
	rm -f -r $(BUILD_ARMV5TE)
	$(call mkdir_make,$(BUILD_ARMV5TE))
	arm-linux-gnueabi-gcc.exe $(GCC_FLAGS) -o $(BUILD_ARMV5TE)/$(OUT) $(C_FILES) $(ARM_STDINC) $(ARM_STDLIBS) $(ARM_LIBS)

i386:
	rm -f -r $(BUILD_I386)
	$(call mkdir_make,$(BUILD_I386))
	i486-linux-gnu-gcc.exe $(GCC_FLAGS) -o $(BUILD_I386)/$(OUT) $(C_FILES) $(I386_STDINC) $(I386_STDLIBS) $(I386_LIBS)

cleanup:
	rm -f -r $(BUILD_ARMV5TE)
	rm -f -r $(BUILD_I386)

